@@ -20,7 +20,7 @@ URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
 URL_UPLOAD_LOG = "/api/client/run/log/upload"
-URL_UPLOAD_FILE = "/res/file/upload"
+URL_UPLOAD_FILE = "/v1/res/file/upload"
 URL_SEND_ALERT = "/api/client/run/alert/send"
 URL_UPDATE_CONFIG = "/api/client/run/config/update"
 URL_FINISH = "/api/client/run/finish"
